@@ -7,7 +7,6 @@ from _pytest.reports import TestReport
 
 from pytest_zebrunner.api.client import ZebrunnerAPI
 from pytest_zebrunner.api.models import (
-    ArtifactReferenceModel,
     CorrelationDataModel,
     FinishTestModel,
     FinishTestSessionModel,
@@ -106,11 +105,6 @@ class ReportingService:
                 ),
             )
 
-        if zebrunner_context.test_is_active:
-            references = [(str(mark.args[0]), str(mark.args[1])) for mark in item.iter_markers("artifact_reference")]
-            models = [ArtifactReferenceModel(name=r[0], value=r[1]) for r in references]
-            self.api.send_artifact_references(models, zebrunner_context.test_run_id, zebrunner_context.test_id)
-
         if report.skipped and zebrunner_context.test_is_active:
             skip_markers = list(filter(lambda x: x.name == "skip", item.own_markers))
             skip_reason = skip_markers[0].kwargs.get("reason") if skip_markers else None
@@ -207,6 +201,6 @@ class ReportingService:
             self.authorize()
             context_data = self.api.get_rerun_tests(run_context)
             rerun_names = {x.correlation_data.name for x in context_data.tests if x.correlation_data is not None}
-            return list(filter(lambda x: x.name in rerun_names, items))
+            return list(filter(lambda x: x.name in rerun_names, items)) if rerun_names else items
         else:
             return items
